import { login, logout, getInfo } from "@/api/login";
import {
  getToken,
  setToken,
  removeToken,
  removeInfo,
  setInfo,
  setCompanyId,
  removeCompanyId,
} from "@/utils/auth";

const user = {
  state: {
    token: getToken(),
    name: "",
    avatar: "",
    roles: [],
    permissions: [],
    info: {},
    companyID: "",
    companyListAll: [],
    messageCount:0
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token;
    },
    SET_NAME: (state, name) => {
      state.name = name;
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar;
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles;
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions;
    },
    SET_INFO: (state, info) => {
      state.info = info;
    },
    SET_COMPANYID: (state, companyID) => {
      state.companyID = companyID;
    },
    SET_COMPANYID_LIST_All: (state, companyListAll) => {
      state.companyListAll = companyListAll;
    },
    SET_MESSAGE_COUNT: (state, messageCount) => {
      state.messageCount = messageCount
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const login_name = userInfo.login_name.trim();
      const password = userInfo.password;
      // const companyID = userInfo.companyID;
      return new Promise((resolve, reject) => {
        login(login_name, password)
          .then((res) => {
            setToken(res.attribute.token);
            setInfo(JSON.stringify(res.attribute.userInfo));
            commit("SET_TOKEN", res.attribute.token);
            commit("SET_INFO", res.attribute.userInfo);
            resolve();
          })
          .catch((error) => {
            console.log(123)
            //
            commit("LogOut")
            reject(error);

          });
      });
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo()
          .then((res) => {
            const user = res.user;
            const avatar =
              user.avatar == "" || user.avatar == null
                ? require("@/assets/images/profile.jpg")
                : process.env.VUE_APP_BASE_API + user.avatar;
            if (res.roles && res.roles.length > 0) {
              // 验证返回的roles是否是一个非空数组
              commit("SET_ROLES", res.roles);
              commit("SET_PERMISSIONS", res.permissions);
            } else {
              commit("SET_ROLES", ["ROLE_DEFAULT"]);
            }
            commit("SET_NAME", user.userName);
            commit("SET_AVATAR", avatar);
            resolve(res);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },

    // 退出系统
    LogOut({ commit, state }) {
      console.log("触发推出")
      return new Promise((resolve, reject) => {
        commit("SET_TOKEN", "");
        commit("SET_ROLES", []);
        commit("SET_PERMISSIONS", []);
        commit("SET_COMPANYID_LIST_All", []);
        removeToken();
        removeInfo();
        removeCompanyId();
        resolve();
      });
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise((resolve) => {
        commit("SET_TOKEN", "");
        removeToken();
        removeInfo();
        resolve();
      });
    },
  },
};

export default user;
